@@ -296,6 +296,9 @@ class RestChannelAsyncClient:
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
+        self.close()
+
+    def close(self) -> None:
         """
         Stops the asynchronous client and terminates the heartbeat thread.
         """
